SafeObject<T> class

=============================== OBJECT (Model)

Constructors

SafeObject(T factory(Map<String, dynamic>))
const

Properties

factory → T Function(Map<String, dynamic>)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(dynamic v) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(T? v) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited